@@ -10,7 +10,7 @@ from ._whatisit import WhatIsItAssertion
 
 
 class TextAssertion(WhatIsItAssertion, ContainAssertion, MatchingAssertion, WhatIsEqualToAssertion):
-    """文本断言"""
+    """内容断言"""
     pass
 
 
