@@ -11,7 +11,7 @@ ERROR_MSG_0006 = (3006, '随机字符串函数只支持传入int类型数字')
 ERROR_MSG_0033 = (3033, 'mysql中无：【{}】库')
 ERROR_MSG_0034 = (3034, 'sql存在语法错误，请检查sql语句：【{}】')
 ERROR_MSG_0035 = (3035, 'sql语句是空，或查询字段或条件字段不存在')
-ERROR_MSG_0047 = (3047, '随机数据方法不存在，请检查输入的方法名称是否正确')
+ERROR_MSG_0047 = (3047, '随机数据方法不存在，请检查输入的方法名称是否正确，方法名称：{}，错误类型：{}')
 ERROR_MSG_0061 = (3061, '前置或者后置的自定义函数没有按照文档规范填写，或者语法不正确，请参照文档后重新填写')
 ERROR_MSG_0014 = (3014, '企微发送失败，请检查企微发送配置')
 ERROR_MSG_0015 = (3015, '的类型错误，请联系管理员进行排查问题')
