@@ -7,11 +7,13 @@ from typing import Optional, Any
 
 from pydantic import BaseModel
 
+
 class MethodModel(BaseModel):
-    f: str
-    p: str | None = None
-    d: bool = False
-    v: Any = None
+    f: str  # 字段名称
+    n: str|None=None  # 字段中文名称
+    p: str | None = None  # 字段在页面的选项
+    d: bool = False  # 字段是否可见
+    v: Any = None  # 字段值
 
 
 class ResponseModel(BaseModel):
@@ -39,15 +41,32 @@ class EmailNoticeModel(BaseModel):
 
 class TestReportModel(BaseModel):
     test_suite_id: int | None = None
-    project_id: int
+    task_name: str | None = None
     project_name: str
+    product_name: str
+
     test_environment: str
+
     case_sum: int
+
+    api_case_sum: int | None = None
+    api_fail: int | None = None
+    api_call: int | None = None
+
+    ui_case_sum: int | None = None
+    ui_fail: int | None = None
+    ui_step_call: int | None = None
+
+    pytest_case_sum: int | None = None
+    pytest_fail: int | None = None
+    pytest_func_call: int | None = None
+
     success: int
     success_rate: float
-    warning: int
+    warning: int = 0
     fail: int
-    execution_duration: int | float
+
+    execution_duration: str
     test_time: str
 
 
